#INCLUDE WCONNECT.H

*************************************************************
DEFINE CLASS HTMLControl AS Custom
*************************************************************
***    Author: Rick Strahl
***            (c) West Wind Technologies, 1996
***   Contact: (541) 386-2087  / rstrahl@west-wind.com
***  Modified: 11/02/96
***
***  Function:
*************************************************************

*** Custom Properties
oReference=.NULL.

*** Stock Properties

************************************************************************
* HTMLControl :: Init
*********************************
***  Function:
***    Assume:
***      Pass:
***    Return:
************************************************************************
FUNCTION Init
LPARAMETERS loObject
ENDFUNC
* Init

************************************************************************
* HTMLControl :: GetHTML
*********************************
***  Function: Retrieves the HTML text for the object based on previous
***            property settings
***      Pass:
***    Return: HTML text for the object
************************************************************************
FUNCTION GetHTML
RETURN ""
* GetHTML

************************************************************************
* HTMLControl :: IsProperty
*********************************
***  Function: Checks to see if a given property exists
***      Pass: lcProperty  -  the property to check
***    Return: .T. or .F.
************************************************************************
FUNCTION IsProperty
LPARAMETERS lcProperty
lcProperty=IIF(type("lcProperty")="C",lcProperty,"")
RETURN PEMSTATUS(THIS.oReference,lcProperty,5)
* IsProperty

************************************************************************
* HTMLControl :: CharValue
*********************************
***  Function: Converts any type of argument to a text variable.
***      Pass:
***    Return:
************************************************************************
FUNCTION CharValue
LPARAMETERS lvValue
LOCAL lvValue, lcValue

lvValue=IIF(type("lvValue")="C",lvValue,THIS.cValue)
lcFieldType=TYPE("lvValue")

DO CASE
         CASE ISNULL(lvValue)
            lcValue="n/a"
         CASE lcfieldtype="C" OR lcfieldtype="M"
            lcValue=TRIM(lvValue) 
         CASE lcfieldtype $ "NFBIY"
            lcValue=LTRIM(STR(lvValue,12,2))
         CASE lcfieldtype="L"
            lcValue=IIF(lvValue,"True","False")
         CASE lcfieldtype="D"
            lcValue=DTOC(lvValue)
         CASE lcfieldtype="T"
            lcValue=ttoc(lvValue)
ENDCASE
         
RETURN lcValue
* EOF CharValue

ENDDEFINE
*EOC HTMLControl


*************************************************************
DEFINE CLASS HTMLInputControl AS HTMLControl
*************************************************************
***    Author: Rick Strahl
***            (c) West Wind Technologies, 1996
***   Contact: (541) 386-2087  / rstrahl@west-wind.com
***  Modified: 11/02/96
***
***  Function:
*************************************************************

*** Custom Properties
cFieldName=""
cValue=""
nWidth=20

*** Stock Properties

************************************************************************
* HTMLInputControl :: Init
*********************************
***  Function: Populates the control with the default properties from
***              
***    Assume:
***      Pass:
***    Return:
************************************************************************
FUNCTION Init
LPARAMETERS loObject


*** If we're passing in a control object use its properties
IF TYPE("loObject")="O"
  THIS.oReference=loObject
  THIS.Left=loObject.left
  THIS.Top=loObject.Top
  THIS.nWidth=loObject.Width
  THIS.cValue=loObject.value
  THIS.cFieldName=loObject.name
ENDIF

ENDFUNC
* Init


************************************************************************
* HTMLControl :: GetHTML
*********************************
***  Function: Retrieves the HTML text for the object based on previous
***            property settings
***      Pass:
***    Return:
************************************************************************
FUNCTION GetHTML
LOCAL lcOutput, lcValue

THIS.cFieldName=IIF(type("THIS.cFieldName")="C",THIS.cFieldName,"Text_"+Sys(3))

lcOutput=[<INPUT NAME="]+THIS.cFieldName+["]
IF !EMPTY(THIS.nWidth)
   lcOutput=lcOutput + [ SIZE="]+LTRIM(STR(THIS.nWidth,5))+["]
ENDIF

*** Convert the value of any type to a character value
lcValue=THIS.CharValue(THIS.cValue)

*** And add to the output string
IF !EMPTY(lcValue)
   lcOutput=lcOutput + [ VALUE="]+TRIM(lcValue)+["]
ENDIF

RETURN lcOutput + ">"
* GetHTML

ENDDEFINE
* HTMLInputControl




*************************************************************
DEFINE CLASS HTMLEditControl AS HTMLControl
*************************************************************
***    Author: Rick Strahl
***            (c) West Wind Technologies, 1996
***   Contact: (541) 386-2087  / rstrahl@west-wind.com
***  Modified: 11/02/96
***
***  Function:
*************************************************************

*** Custom Properties
cFieldName=""
cValue=""
nWidth=20
nHeight=5

*** Stock Properties

************************************************************************
* HTMLEditControl :: Init
*********************************
***  Function: Populates the control with the default properties from
***              
***    Assume:
***      Pass:
***    Return:
************************************************************************
FUNCTION Init
LPARAMETERS loObject


*** If we're passing in a control object use its properties
IF TYPE("loObject")="O"
  THIS.oReference=loObject
  THIS.nWidth=loObject.Width
  THIS.nHeight=loObject.Height
  THIS.cValue=loObject.value
  THIS.cFieldName=loObject.name
ENDIF

ENDFUNC
* Init


************************************************************************
* HTMLEditControl :: GetHTML
*********************************
***  Function: Retrieves the HTML text for the object based on previous
***            property settings
***      Pass:
***    Return:
************************************************************************
FUNCTION GetHTML
LOCAL lcOutput, lcValue

THIS.cFieldName=IIF(type("THIS.cFieldName")="C",THIS.cFieldName,"Text_"+Sys(3))

lcOutput=[<TEXTAREA NAME="]+THIS.cFieldName+["]
IF !EMPTY(THIS.nWidth)
   lcOutput=lcOutput + [ COLS="]+LTRIM(STR(THIS.nWidth  * 1.5,5)) +["]
ENDIF
IF !EMPTY(THIS.nHeight)
   lcOutput=lcOutput + [ ROWS="]+LTRIM(STR(THIS.nHeight,5))+[">]
ENDIF

*** Convert the value of any type to a character value
lcValue=THIS.CharValue(THIS.cValue)

*** And add to the output string
IF !EMPTY(lcValue)
   lcOutput=lcOutput + TRIM(lcValue)
ENDIF

RETURN lcOutput + "</TEXTAREA>"
* GetHTML

ENDDEFINE
* HTMLEditControl


*************************************************************
DEFINE CLASS HTMLLabelControl AS HTMLControl
*************************************************************
***    Author: Rick Strahl
***            (c) West Wind Technologies, 1996
***   Contact: (541) 386-2087  / rstrahl@west-wind.com
***  Modified: 11/02/96
***
***  Function:
*************************************************************

*** Custom Properties
*** Custom Properties
cValue=""
lBold=.F.
cFont=""
nFontSize=0
nFontColor=0

*** Stock Properties


************************************************************************
* HTMLLabelControl :: Init
*********************************
***  Function: Populates the control with the default properties from
***              
***    Assume:
***      Pass:
***    Return:
************************************************************************
FUNCTION Init
LPARAMETERS loObject

*** If we're passing in a control object use its properties
*** Otherwise these properties aren't set and can be set
*** manually by accessing the properties of the class
IF TYPE("loObject")="O"
  THIS.oReference=loObject
  THIS.cValue=STRTRAN(loObject.Caption,"\<","")
  THIS.cFont=loObject.Fontname
  THIS.nFontSize=loObject.FontSize
  THIS.nFontColor=loObject.ForeColor
  THIS.lBold=loObject.FontBold
ENDIF

ENDFUNC
* Init


************************************************************************
* HTMLLabelControl :: GetHTML
*********************************
***  Function: Retrieves the HTML text for the object based on previous
***            property settings
***      Pass:
***    Return:
************************************************************************
FUNCTION GetHTML
LOCAL lcOutput, lcValue, lnFontSize, loHTML1

lcOutput=THIS.cValue

IF !EMPTY(THIS.cFont) AND !EMPTY(THIS.nFontSize)
   lcFont=[<FONT]
   IF !EMPTY(THIS.cFont)
      lcFont=lcFont+[ FACE="]+THIS.cFont+["]
   ENDIF
   IF !EMPTY(THIS.nFontSize)
      DO CASE
         CASE THIS.nFontSize < 9
           lnFontSize=1
         CASE THIS.nFontSize=9 or THIS.nFontSize=10
           lnFontSize=2
         CASE THIS.nFontSize=11 or THIS.nFontSize=12
           lnFontSize=3
         CASE THIS.nFontSize>=13  or THIS.nFontSize<16
           lnFontSize=4
         CASE THIS.nFontSize>=16  or THIS.nFontSize<=20
           lnFontSize=5
         CASE THIS.nFontSize>=20  or THIS.nFontSize<=24
           lnFontSize=6
      ENDCASE
      lcFont=lcFont+[ SIZE="]+LTRIM(STR(lnFontSize))+["]
   ENDIF
   IF !EMPTY(THIS.nFontColor)
      loHTML1=CREATE("wwHTMLString")
      lcFont=lcFont+[ COLOR="]+loHTML1.HTMLColor(THIS.nFontColor,.t.)+["]
   ENDIF   
   lcOutput=lcFont + [>] + lcOutput + [</FONT>]
ENDIF
IF !EMPTY(THIS.lBold)
   lcOutput=[<b>]+lcOutput+[</b>]
ENDIF

RETURN lcOutput 
* GetHTML


ENDDEFINE
*EOC HTMLLabelControl







*************************************************************
DEFINE CLASS HTMLButtonControl AS HTMLControl
*************************************************************
***    Author: Rick Strahl
***            (c) West Wind Technologies, 1996
***   Contact: (541) 386-2087  / rstrahl@west-wind.com
***  Modified: 11/02/96
***
***  Function:
*************************************************************

*** Custom Properties
*** Custom Properties
cValue=""
lBold=.F.
cFont=""
nFontSize=0

nWidth=10

*** Stock Properties


************************************************************************
* HTMLLabelControl :: Init
*********************************
***  Function: Populates the control with the default properties from
***              
***    Assume:
***      Pass:
***    Return:
************************************************************************
FUNCTION Init
LPARAMETERS loObject

*** If we're passing in a control object use its properties
*** Otherwise these properties aren't set and can be set
*** manually by accessing the properties of the class
IF TYPE("loObject")="O"
  THIS.oReference=loObject
  THIS.cValue=STRTRAN(loObject.Caption,"\<","")
  THIS.cFont=loObject.Fontname
  THIS.nFontSize=loObject.FontSize
  THIS.lBold=loObject.FontBold
ENDIF

ENDFUNC
* Init


************************************************************************
* HTMLLabelControl :: GetHTML
*********************************
***  Function: Retrieves the HTML text for the object based on previous
***            property settings
***      Pass:
***    Return:
************************************************************************
FUNCTION GetHTML
LOCAL lcOutput, lcValue, lnFontSize

lcOutput=THIS.cValue

IF !EMPTY(THIS.cFont) AND !EMPTY(THIS.nFontSize)
   lcFont=[<FONT]
   IF !EMPTY(THIS.cFont)
      lcFont=lcFont+[ FACE="]+THIS.cFont+["]
   ENDIF
   IF !EMPTY(THIS.nFontSize)
      DO CASE
         CASE THIS.nFontSize=8 or THIS.nFontSize=9
           lnFontSize=2
         CASE THIS.nFontSize=10 or THIS.nFontSize=11
           lnFontSize=3
         CASE THIS.nFontSize>=12  or THIS.nFontSize<14
           lnFontSize=4
         CASE THIS.nFontSize>=16  or THIS.nFontSize<=20
           lnFontSize=5
         CASE THIS.nFontSize>=20  or THIS.nFontSize<=24
           lnFontSize=6
      ENDCASE
      lcFont=lcFont+[ SIZE="]+LTRIM(STR(lnFontSize))+["]
   ENDIF
   lcOutput=lcFont + [>] + lcOutput + [</FONT>]
ENDIF
IF !EMPTY(THIS.lBold)
   lcOutput=[<b>]+lcOutput+[</b>]
ENDIF

RETURN lcOutput 
* GetHTML


ENDDEFINE
*EOC HTMLLabelControl


*************************************************************
DEFINE CLASS HTMLCheckboxControl AS HTMLControl
*************************************************************
***    Author: Rick Strahl
***            (c) West Wind Technologies, 1996
***   Contact: (541) 386-2087  / rstrahl@west-wind.com
***  Modified: 11/02/96
***
***  Function:
*************************************************************

*** Custom Properties
cFieldName=""
cValue=0
lChecked=.F.
cCaption=""

*** Stock Properties

************************************************************************
* HTMLCheckBoxControl :: Init
*********************************
***  Function: Populates the control with the default properties from
***      Pass: loObject -  Form Control
************************************************************************
FUNCTION Init
LPARAMETERS loObject

*** If we're passing in a control object use its properties
IF TYPE("loObject")="O"
  THIS.oReference=loObject
  THIS.cValue=loObject.value
  IF TYPE("THIS.cValue")="N"
     THIS.cValue=IIF(THIS.cValue=0,"NO","YES")
  ENDIF
  IF TYPE("THIS.cValue")="L"
     THIS.cValue=IIF(THIS.cValue,"YES","NO")
  ENDIF
  IF THIS.cValue="YES"
     THIS.lChecked=.T.
  ENDIF
  THIS.cFieldName=loObject.name
  THIS.cCaption=loObject.caption
ENDIF

ENDFUNC
* Init


************************************************************************
* HTMLCheckboxControl :: GetHTML
*********************************
***  Function: Retrieves the HTML text for the object based on previous
***            property settings
***    Return: HTML for control
************************************************************************
FUNCTION GetHTML
LOCAL lcOutput, lcValue

THIS.cFieldName=IIF(type("THIS.cFieldName")="C",THIS.cFieldName,"Check_"+Sys(3))

lcOutput=[<INPUT TYPE="CHECKBOX" NAME="]+THIS.cFieldName+["]

IF THIS.lChecked
   lcOutput=lcOutput + [ CHECKED]
ENDIF   

*** Call the Label Control object to display the actual label
loLabel=CREATE("HTMLLabelControl",THIS.oReference)

RETURN lcOutput + ">"  + loLabel.GetHTML()
* GetHTML

ENDDEFINE
* HTMLCheckboxControl


*************************************************************
DEFINE CLASS HTMLRadioControl AS HTMLControl
*************************************************************
***    Author: Rick Strahl
***            (c) West Wind Technologies, 1996
***   Contact: (541) 386-2087  / rstrahl@west-wind.com
***  Modified: 11/02/96
***
***  Function:
*************************************************************

*** Custom Properties
cFieldName=""
cValue=0
lChecked=.F.
cCaption=""

*** Stock Properties

************************************************************************
* HTMLRadioControl :: Init
*********************************
***  Function: Populates the control with the default properties from
***      Pass: loObject -  Form Control
************************************************************************
FUNCTION Init
LPARAMETERS loObject

*-* <p><input type="radio" checked name="SpecialType"
*-*                value="1">Weekly Specials <input type="radio"
*-*                name="SpecialType" value="2">Email Specials <input
*-*                type="radio" name="SpecialType" value="3">Banner
*-*                Specials <input type="radio" name="SpecialType"
*-*                value="4">Free Items</p>
                
*** If we're passing in a control object use its properties
IF TYPE("loObject")="O"
  THIS.oReference=loObject
  THIS.cValue=loObject.value
  IF TYPE("THIS.cValue")="N"
     THIS.cValue=IIF(THIS.cValue=0,"NO","YES")
  ENDIF
  IF TYPE("THIS.cValue")="L"
     THIS.cValue=IIF(THIS.cValue,"YES","NO")
  ENDIF
  IF THIS.cValue="YES"
     THIS.lChecked=.T.
  ENDIF

  *** Fieldname we want is really the option group
  THIS.cFieldName=loObject.parent.name
  THIS.cCaption=loObject.caption
ENDIF

ENDFUNC
* Init


************************************************************************
* HTMLRadioControl :: GetHTML
*********************************
***  Function: Retrieves the HTML text for the object based on previous
***            property settings
***    Return: HTML for control
************************************************************************
FUNCTION GetHTML
LOCAL lcOutput, lcValue

THIS.cFieldName=IIF(type("THIS.cFieldName")="C",THIS.cFieldName,"Radio_"+Sys(3))

lcOutput=[<INPUT TYPE="radio" NAME="]+THIS.cFieldName+["]

IF THIS.lChecked
   lcOutput=lcOutput + [ CHECKED]
ENDIF   

*** Call the Label Control object to display the actual label
loLabel=CREATE("HTMLLabelControl",THIS.oReference)

RETURN lcOutput + ">"  + loLabel.GetHTML()
* GetHTML

ENDDEFINE
* HTMLCheckboxControl



*************************************************************
DEFINE CLASS HTMLButtonControl AS HTMLControl
*************************************************************
***    Author: Rick Strahl
***            (c) West Wind Technologies, 1996
***   Contact: (541) 386-2087  / rstrahl@west-wind.com
***  Modified: 11/02/96
***
***  Function:
*************************************************************

*** Custom Properties
cFieldName=""
cCaption=""
nWidth=10

*** Stock Properties

************************************************************************
* HTMLCheckBoxControl :: Init
*********************************
***  Function: Populates the control with the default properties from
***      Pass: loObject -  Form Control
************************************************************************
FUNCTION Init
LPARAMETERS loObject

*** If we're passing in a control object use its properties
IF TYPE("loObject")="O"
  THIS.oReference=loObject
  THIS.cFieldName=loObject.name
  THIS.nWidth=loObject.Width
  THIS.cCaption=STRTRAN(loObject.caption,"\<","")
ENDIF

ENDFUNC
* Init


************************************************************************
* HTMLButtonControl :: GetHTML
*********************************
***  Function: Retrieves the HTML text for the object based on previous
***            property settings
***    Return: HTML for control
************************************************************************
FUNCTION GetHTML
LOCAL lcOutput, lcValue

THIS.cFieldName=IIF(type("THIS.cFieldName")="C",THIS.cFieldName,"Button_"+Sys(3))

lcOutput=[<INPUT TYPE="SUBMIT" NAME="]+THIS.cFieldName+["]

lcOutput=lcOutput + [ VALUE="]+THIS.cCaption+["]
lcOutput=lcOutput + [ WIDTH="]+LTRIM(STR(THIS.nWidth))+["]

RETURN lcOutput + ">"
* GetHTML

ENDDEFINE
* HTMLButtonControl


*************************************************************
DEFINE CLASS HTMLComboControl AS HTMLControl
*************************************************************
***    Author: Rick Strahl
***            (c) West Wind Technologies, 1996
***   Contact: (541) 386-2087  / rstrahl@west-wind.com
***  Modified: 11/02/96
***
***  Function:
*************************************************************

*** Custom Properties
cFieldName=""
cValue=""
nWidth=20

*** Stock Properties

************************************************************************
* HTMLComboControl :: Init
*********************************
***  Function: Populates the control with the default properties from
***              
***    Assume:
***      Pass:
***    Return:
************************************************************************
FUNCTION Init
LPARAMETERS loObject

*** If we're passing in a control object use its properties
IF TYPE("loObject")="O"
  THIS.oReference=loObject
  THIS.Width=loObject.Width
  THIS.cValue=loObject.value
  THIS.cFieldName=loObject.name
ENDIF

ENDFUNC
* Init


************************************************************************
* HTMLControl :: GetHTML
*********************************
***  Function: Retrieves the HTML text for the object based on previous
***            property settings
***      Pass:
***    Return:
************************************************************************
FUNCTION GetHTML
LOCAL lcOutput, lcValue, x, loList

THIS.cFieldName=IIF(type("THIS.cFieldName")="C",THIS.cFieldName,"Text_"+Sys(3))

lcOutput=CR+[<SELECT NAME="]+THIS.cFieldName+[" SIZE="1"]

IF !EMPTY(THIS.nWidth)
   lcOutput=lcOutput + [ COLS="]+LTRIM(STR(THIS.nWidth,5))+["]
ENDIF

lcOutput=lcOutput+[>]+CR

*** Convert the value of any type to a character value
lcValue=THIS.CharValue(THIS.cValue)

loList=THIS.oReference

FOR x=1 to loList.ListCount
  lcText=loList.ListItem[x]
  IF UPPER(lcText)=UPPER(TRIM(lcValue))
     lcOutput=lcOutput+[<OPTION SELECTED>]+lcText+CR
  ELSE
     lcOutput=lcOutput+[<OPTION>]+lcText+CR
  ENDIF
ENDFOR

lcOutput=lcOutput + "</SELECT>" + CR

RETURN lcOutput
* GetHTML

ENDDEFINE
* HTMLComboControl

*************************************************************
DEFINE CLASS HTMLCommandGroup AS HTMLControl
*************************************************************
***    Author: Rick Strahl
***            (c) West Wind Technologies, 1996
***   Contact: (541) 386-2087  / rstrahl@west-wind.com
***  Modified: 11/02/96
***
***  Function:
*************************************************************

*** Custom Properties
cFieldName=""
cValue=""
nWidth=20

*** Stock Properties

************************************************************************
* HTMLCommandGroup :: Init
*********************************
***  Function: Populates the control with the default properties from
***              
***    Assume:
***      Pass:
***    Return:
************************************************************************
FUNCTION Init
LPARAMETERS loObject

*** If we're passing in a control object use its properties
IF TYPE("loObject")="O"
  THIS.oReference=loObject
  THIS.Width=loObject.Width
  THIS.cFieldName=loObject.name
ENDIF

ENDFUNC
* Init


************************************************************************
* HTMLCommandGroup :: GetHTML
*********************************
***  Function: Retrieves the HTML text for the object based on previous
***            property settings
***      Pass:
***    Return:
************************************************************************
FUNCTION GetHTML
LOCAL lcOutput, lcValue, x, loList

loContainer=THIS.oReference
llDirection=loContainer

lcOutput=""


*** For now assume buttons are horizontal only
FOR x=1 to loContainer.ButtonCount
    loObject=loContainer.Buttons[x]
    loButton=CREATE("HTMLButtonControl",loObject)
    lcOutput=lcOutput+loButton.GetHTML() 
ENDFOR && x=1 to loContainer.ButtonCount

RETURN lcOutput
* GetHTML

ENDDEFINE
* HTMLComboControl
