************************************************************************
*FUNCTION CGIMAIN
******************
***    Author: Rick Strahl
***            (c) West Wind Technologies, 1995
***   Contact: (541) 386-2087  / rstrahl@west-wind.com
***  Modified: 11/15/96
***  Function: Web Connection demonstration program. This program
***            constitutes the mainline program that starts up the
***            server.
***            
***            The server then calls the Process procedure in this
***            PRG file, which in turn calls the actual demo
***            program file called wwDemo.
***            
***            wwDemo.prg contains all the Web request/application
***            logic in a class with multiple response methods.
***            wwDemo acts as a container for multiple request
***            handlers and groups these requests.
***            
***            You can create and add separate 'applications' by
***            building additional PRG files containing classes that
***            match the structure in wwDemo.prg. To do so the PRG
***            file must be added to the Process procedure
***
***    Assume: called from WCONNECT.HTM form test.
***            Web server is running and calling
***            \cgi-win\wwcgi.dll?Program~Method~OptionalParm1~OptionalParm2
***            \cgi-win\wwcgi.dll?wwDemo~TestMethod~Parm2
***
***     Notes: Uses Settings class to retrieve startup values
***            from CGIMAIN.INI. 
************************************************************************
LOCAL lcOldError, loAPI

#INCLUDE FOXPRO.H
#INCLUDE WCONNECT.H

PUBLIC glExitCGIServer, glRecycle, goSettings, oCGIServer

glExitCGIServer=.F.
glRecycle=.F.

DO WHILE !glExitCGIServer
   *** Note you might have to reset some of these
   *** in your code if you use Data Environments
   SET SAFETY OFF
   SET EXACT OFF
   SET TALK OFF
   SET DELETED ON
   SET ESCAPE ON
   SET CPDIALOG OFF

      
   #IF !DEBUGMODE
     SET DEBUG OFF
     SET STATUS BAR OFF
     SET DEVELOP OFF
     SET SYSMENU OFF
   #ENDIF

   *** Allow shut down by system
   ON SHUTDOWN DO ShutIt IN CGIMAIN.PRG
   
   #IF SHAREWARE
     DO WCONNECT.APP
   #ELSE   
     SET PROCEDURE TO CGIServ ADDITIVE
     SET PROCEDURE TO CGI ADDITIVE
     SET PROCEDURE TO HTML ADDITIVE
     SET PROCEDURE TO CGIPROC ADDITIVE
     SET PROCEDURE TO wwUTILS ADDITIVE
     SET PROCEDURE TO wwBanner ADDITIVE
   #ENDIF
    
   * SET PROCEDURE TO NETSCAPE ADDITIVE

   *** Add any program file paths here
   DO PATH WITH "WWDEMO"
         
   *** Retrieve INI file settings or defaults
   *** NOTE: This is a PUBLIC object! This file is CGIMAIN.INI
   oSettings=CREATE("Settings",".\cgimain.ini")

   IF NOT oSettings.lDebugMode
     *** Enable Error Handler only if DEBUGMODE is set ON
     ON ERROR DO ErrorHandler WITH ;
              ERROR(),MESSAGE(),MESSAGE(1),SYS(16),LINENO()
   ENDIF

   *** Create an instance of the CGIServer 
   oCGIServer=CREATE("wwCGIServer","Process")

   *** When running Netscape a special CGI class is required
   *** oCGIServer.SetCGIClass("wwNetscapeCGI")   
   
   IF TYPE("oCGIServer")#"O"
      =MessageBox("Unable to load the CGI Request Server",;
         MB_ICONEXCLAMATION,"Web Connection Error")
      RETURN
   ENDIF
   
   *** You can also force the CGI server to process requests
   *** on a remote server, thus scaling the load to
   *** multiple processors. Point at the CGI temp file directory
   *** over the network with this method.
   oCGIServer.SetCGIFilePath(oSettings.cPath) 

   *** A few system settings - pulled from CGIMAIN.INI
   oCGIServer.SetForegroundTasking(oSettings.nPriority)  && 1 - NT  2 - Win95
   oCGIServer.SetTimerInterval(oSettings.nTimerInterval) && 200 
   oCGIServer.SetCGIFileTemplate(oSettings.cTemplate)    && WC_ 
   
   *** Set these off for better performance
   oCGIServer.SetStatusWindow(oSettings.lShowStatus)
   oCGIServer.SetLogToFile(oSettings.lLogToFile)
   
   RELEASE oSettings
   
   *** This actually puts the server into polling mode
   *** Displays a modal window 
   oCGIServer.show()
   READ EVENTS
   
   *** Done
   ON SHUTDOWN
ENDDO

ON ERROR
RELEASE glExitCGIServer

SET SYSMENU ON
SET DEBUG ON
SET STATUS BAR ON
SET DEVELOP ON

RETURN


************************************************************************
FUNCTION Process
******************
***  Modified: 01/24/96
***  Function: This procedure's main purpose is to route incoming
***            CGI requests to individual project PRGs/APPs.
***
***            The URL formatting used is as follows:
***            /cgi-win/wwcgi.dll?project~task~Optional+Parms
***
***            The project 'parameter' is routed to the appropriate
***            program file which actually implements a Process class
***            to respond to CGI requests.
***             
***            Several Maintaince functions are provided directly in
***            this program file: ShowLog, Clear Log and Recycle (Server).
***
***      Pass: loCGI	-	Object containing CGI information
***    Return: .T. to erase Temp File .F. to keep it
************************************************************************
LPARAMETERS loCGI


IF TYPE("loCGI")#"O"
   *** Make sure object was passed -
   *** Nope - This will cause a server error,
   *** but we can't work without the CGI info
   RETURN .F.
ENDIF
   
*** Optional CGI parameters following EXE name
*** Format: /cgi-win/wwcgi.dll?wwdemo~Project~Method~Other+Parameters
loCGI.aCGIParms()                            && Create Array of parameters 
lcParameter=UPPER(loCGI.GetCGIParameter(1))  && Get first Parameter (Project)

*** The following is the meat: This calls your custom code. Each PRG
*** file needs to be 'registered' here in the CASE statement. This is done
*** for security reasons so only the programs you specify here can actually
*** be called.
DO CASE
  CASE lcParameter="WWDEMO"
     DO wwDemo with loCGI

*** Put any other PRG files that are called below:

***  CASE lcParameter="THREADS"
***     DO THREADS WITH loCGI

***  CASE lcParameter="MYCODE"
***     DO MyCode with loCGI

  *** SYSTEM TASKS
  CASE lcParameter="WWMAINT"
     DO wwMaint with loCGI
     
  OTHERWISE
     *** ERROR - don't know what to do with request
     ***         Create generic error page.
     loHTML=CREATE("wwHTML",loCGI.GetOutFile())
     IF TYPE("loHTML")#"O"
        *** This will cause a server error, but we
        *** can't work without the CGI info
        RETURN .F.
     ENDIF
     loHTML.HTMLError("Unhandled CGI Request",;
                  "The server is not setup to handle this type of CGI Request",;
                  loCGI.GetServerAdmin(), loCGI.GetPreviousUrl())
ENDCASE

*** DEBUG: Copy the output HTML and INI file to temp files to review
* RELEASE LOHTML
* COPY FILE (loCGI.GetContentFile()) TO TEMP.INI  
* COPY FILE (loCGI.GetOutFile()) TO TEMP.HTM  
RETURN


************************************************************************
PROCEDURE ErrorHandler
**********************
***  Modified: 12/31/95
***  Function: Global Error handler. Shuts down everything then
***            restarts the server from scratch. Used to make sure the
***            server is always running. This error handler will write
***            an error to the log, but won't output an HTML document.
***
***            Note that local error handlers in the Process class
***            or other classes will override the global handler.
*************************************************************************
PARAMETER t_errorno,t_mess1,t_mess2,t_module,t_lineno
LOCAL llOldLogging, lcProcess

*** Further errors should be ignored here
ON ERROR *

IF TYPE("oCGIServer")="O"
   IF TYPE("oCGIServer.oCGI")="O"  
      lcProcess= CR+oCGIServer.oCGI.GetCGIParameter()+CR+CR
   ELSE
      lcProcess=""
   ENDIF

   llOldLogging=oCGIServer.GetLogToFile()
   oCGIServer.SetLogToFile(.T.)
   oCGIServer.LogEntry("Processing Error<br>"+CR+;
                       lcProcess+CR+;
                       "<PRE>"+CR+;
                       "Error: "+STR(T_errorno)+CR+;
                       "Message: "+T_Mess1+CR+;
                       "Code: "+T_mess2+CR+;
                       "Program: "+T_Module+CR+;
                       "Line No: "+STR(T_lineno)+CR+"</PRE>",;
                       "Local",0)
  
   oCGIServer.SetLogToFile(llOldLogging)
ENDIF

CLOSE DATA

RELEASE WINDOWS  && Release CGI Server Window and moves code on

*** Restart - ie. hit the main loop w/o the glExitServer flag set

RETURN TO MASTER

************************************************************************
PROCEDURE Shutit
******************
***  Function: System Shutdown Procedure
*************************************************************************
ON ERROR *
RELEASE oCGIServer
QUIT
RETURN
